unit fmEntVal;

interface

uses
  Buttons, Classes, Controls, ExtCtrls, Forms, StdCtrls;

type
  TfrmEnterValue = class(TForm)
    bvlValueBorder: TBevel;
    lblParameterName: TLabel;
    edtValue: TEdit;
    btnOK: TBitBtn;
    btnCancel: TBitBtn;
    procedure btnOKClick(Sender : TObject);
  private
    FMinimumValue : Integer;
    FMaximumValue : Integer;
    function GetValue : Integer;
    procedure SetValue(const NewValue : Integer);
  public
    property MinimumValue : Integer read FMinimumValue write FMinimumValue;
    property MaximumValue : Integer read FMaximumValue write FMaximumValue;
    property Value : Integer read GetValue write SetValue;
  end;

var
  frmEnterValue : TfrmEnterValue;

function EnterValue(const ParameterName : String;
                    const CurrentValue, MinValue, MaxValue  : Integer) : Integer;

implementation

uses
  SysUtils, WinProcs, WinTypes;

{$R *.DFM}

function EnterValue(const ParameterName : String;
                    const CurrentValue, MinValue, MaxValue  : Integer) : Integer;

var
  frmEnterValue : TfrmEnterValue;

begin
  frmEnterValue := TfrmEnterValue.Create(Application.MainForm);
  try
    with frmEnterValue do
    begin
      Caption := 'Enter ' + ParameterName;
      lblParameterName.Caption := '&' + ParameterName;
      MinimumValue := MinValue;
      MaximumValue := MaxValue;
      Value := CurrentValue;
      if ShowModal = mrOK then
        Result := Value
      else
        Result := CurrentValue
    end
  finally
    frmEnterValue.Free
  end
end;

procedure TfrmEnterValue.btnOKClick(Sender : TObject);

var
  ErrorMessage : String;

begin
  if Value < MinimumValue then
    ErrorMessage := ' must be at least ' + IntToStr(MinimumValue)
  else
    if Value > MaximumValue then
      ErrorMessage := ' must be no more than ' + IntToStr(MaximumValue);
  if Length(ErrorMessage) > 0 then
  begin
    MessageBeep(MB_ICONHAND);
{
    MessageBox(Handle, Copy(lblParameterName.Caption, 2, MaxInt) + ErrorMessage,
               'Error', MB_ICONERROR or MB_OK)
}
  end
  else
    ModalResult := mrOK
end;

function TfrmEnterValue.GetValue : Integer;

begin
  Result := StrToInt(edtValue.Text)
end;

procedure TfrmEnterValue.SetValue(const NewValue : Integer);

begin
  edtValue.Text := IntToStr(NewValue)
end;

end.
