unit fmMain;

interface

uses
  Buttons, Classes, Controls, ExtCtrls, Forms, Menus, Messages, StdCtrls, ULife;

type
  TfrmMain = class(TForm)
    mnuMain: TMainMenu;
    mniFile: TMenuItem;
    mniFileExit: TMenuItem;
    mniOptions: TMenuItem;
    mniOptionsWidth: TMenuItem;
    mniOptionsHeight: TMenuItem;
    mniOptionsDivider: TMenuItem;
    mniOptionsSpeed: TMenuItem;
    pnlToolBar: TPanel;
    bvlToolBarTopBorder: TBevel;
    btnStep: TSpeedButton;
    btnStart: TSpeedButton;
    btnToolBarDivider: TBevel;
    btnSetCells: TSpeedButton;
    btnClear: TSpeedButton;
    btnRandomise: TSpeedButton;
    bvlToolBarBottomBorder: TBevel;
    cmpLife: TLife;
    pnlInformation: TPanel;
    lblGeneration: TLabel;
    lblGenerationValue: TLabel;
    lblCells: TLabel;
    lblCellsValue: TLabel;
    pnlStatusLine: TPanel;
    tmrNextGeneration: TTimer;
    procedure btnClearClick(Sender : TObject);
    procedure btnRandomiseClick(Sender : TObject);
    procedure btnSetCellsClick(Sender : TObject);
    procedure btnStepClick(Sender : TObject);
    procedure btnStartClick(Sender : TObject);
    procedure cmpLifeChange(Sender : TObject);
    procedure FormCreate(Sender : TObject);
    procedure Minimised(Sender : TObject);
    procedure mniFileExitClick(Sender : TObject);
    procedure mniOptionsHeightClick(Sender : TObject);
    procedure mniOptionsSpeedClick(Sender : TObject);
    procedure mniOptionsWidthClick(Sender : TObject);
    procedure Restored(Sender : TObject);
    procedure ShowHint(Sender : TObject);
    procedure tmrNextGenerationTimer(Sender : TObject);
  private
    FIsMinimised : Boolean;
    procedure UpdateMenusAndButtons;
  protected
    procedure WMGetMinMaxInfo(var Message : TWMGetMinMaxInfo); message WM_GETMINMAXINFO;
  end;

var
  frmMain : TfrmMain;

implementation

uses
  fmEntVal, SysUtils;

{$R *.DFM}

procedure TfrmMain.btnClearClick(Sender : TObject);

begin
  cmpLife.ClearCells
end;

procedure TfrmMain.btnRandomiseClick(Sender : TObject);

var
  x : Integer;
  y : Integer;

begin
  with cmpLife do
    for x := 0 to GridWidth - 1 do
      for y := 0 to GridHeight - 1 do
        if Random < 0.5 then
          Cells[x, y] := True
        else
          Cells[x, y] := False
end;

procedure TfrmMain.btnSetCellsClick(Sender : TObject);

begin
  with cmpLife do
  begin
    AcceptMouseClicks := btnSetCells.Down;
    ShowGridLines := AcceptMouseClicks
  end
end;

procedure TfrmMain.btnStepClick(Sender : TObject);

begin
  cmpLife.NextGeneration
end;

procedure TfrmMain.btnStartClick(Sender : TObject);

begin
  tmrNextGeneration.Enabled := btnStart.Down;
  UpdateMenusAndButtons
end;

procedure TfrmMain.cmpLifeChange(Sender : TObject);

begin
  lblGenerationValue.Caption := ' ' + IntToStr(cmpLife.Generation);
  lblCellsValue.Caption := ' ' + IntToStr(cmpLife.LiveCells);
  if FIsMinimised then
    Application.Title := 'Life - Generation ' + IntToStr(cmpLife.Generation);
  UpdateMenusAndButtons
end;

procedure TfrmMain.FormCreate(Sender : TObject);

begin
  Application.OnHint := ShowHint;
  Application.OnMinimize := Minimised;
  Application.OnRestore := Restored;
  cmpLife.GridWidth := 20;
  Randomize
end;

procedure TfrmMain.Minimised(Sender : TObject);

begin
  FIsMinimised := True
end;

procedure TfrmMain.mniFileExitClick(Sender : TObject);

begin
  Close
end;

procedure TfrmMain.mniOptionsHeightClick(Sender : TObject);

begin
  with cmpLife do
    GridHeight := EnterValue('Height', GridHeight, MinGridHeight, MaxGridHeight)
end;

procedure TfrmMain.mniOptionsSpeedClick(Sender : TObject);

begin
  with tmrNextGeneration do
    Interval := EnterValue('Speed', Interval, 1, 2000)
end;

procedure TfrmMain.mniOptionsWidthClick(Sender : TObject);

begin
  with cmpLife do
    GridWidth := EnterValue('Width', GridWidth, MinGridWidth, MaxGridWidth)
end;

procedure TfrmMain.Restored(Sender : TObject);

begin
  FIsMinimised := False;
  Application.Title := 'Life'
end;

procedure TfrmMain.ShowHint(Sender : TObject);

begin
  pnlStatusLine.Caption := Application.Hint
end;

procedure TfrmMain.tmrNextGenerationTimer(Sender : TObject);

begin
  cmpLife.NextGeneration
end;

procedure TfrmMain.UpdateMenusAndButtons;

begin
  mniOptions.Enabled := not btnStart.Down and not btnSetCells.Down;
  btnStep.Enabled := not btnStart.Down and not btnSetCells.Down;
  with btnStart do
  begin
    Enabled := not btnSetCells.Down;
    if Down then
    begin
      Caption := 'Stop';
      Hint := 'Stop stepping through the generations'
    end
    else
    begin
      Caption := 'Start';
      Hint := 'Automatically step through the generations'
    end
  end;
  btnSetCells.Enabled := not btnStart.Down;
  btnClear.Enabled := btnSetCells.Down and (cmpLife.LiveCells > 0);
  btnRandomise.Enabled := btnSetCells.Down
end;

procedure TfrmMain.WMGetMinMaxInfo(var Message : TWMGetMinMaxInfo);

begin
  Inherited;
  with Message.MinMaxInfo^.ptMinTrackSize do
  begin
    x := 416;
    y := 200
  end
end;

end.
