{*******************************************************************************}
{                                                                               }
{ FileName     : fmScreenSaver.pas                                              }
{                                                                               }
{ Author       : Ian Lane (Email: lanei@ideal.net.au)                           }
{                                                                               }
{ Synopsis     : This is our actual screen saver descended from frmBaseScreen.  }
{                                                                               }
{ Distribution : This program is free for public use as long as credit is given }
{                to the author.                                                 }
{                                                                               }
{                          Copyright (c) 1998 Ian Lane                          }
{                                                                               }
{*******************************************************************************}
unit fmScreenSaver;

interface

uses
  Classes, Controls, ExtCtrls, fmBaseScreen, Forms, Messages, ULife, Windows;
  
type
  TfrmScreenSaver = class(TfrmBaseScreen)
    procedure cmpLifeMouseDown(Sender : TObject; Button : TMouseButton; Shift : TShiftState;
                               X, Y : Integer);
    procedure cmpLifeMouseMove(Sender : TObject; Shift : TShiftState; X, Y : Integer);
    procedure FormCreate(Sender : TObject);
    procedure FormDestroy(Sender : TObject);
  private
    FLastNotifiedMousePosition : TPoint;
    procedure WMKeyDown(var Msg : TWMKeyDown); message WM_KEYDOWN;
    procedure WMSysKeyDown(var Msg : TWMSysKeyDown); message WM_SYSKEYDOWN;
  end;

var
  frmScreenSaver : TfrmScreenSaver;

implementation

{$R *.DFM}

const
  MouseSensitivity = 20;

procedure TfrmScreenSaver.cmpLifeMouseDown(Sender : TObject; Button : TMouseButton;
                                           Shift : TShiftState; X, Y : Integer);

begin
  Inherited;
  Close
end;

procedure TfrmScreenSaver.cmpLifeMouseMove(Sender : TObject; Shift : TShiftState;
                                           X, Y : Integer);

begin
  Inherited;
  if FLastNotifiedMousePosition.X < 0 then
  begin
    FLastNotifiedMousePosition.X := X;
    FLastNotifiedMousePosition.Y := Y
  end
  else
    if (Abs(FLastNotifiedMousePosition.X - X) > MouseSensitivity) or
       (Abs(FLastNotifiedMousePosition.Y - Y) > MouseSensitivity) then
      Close

end;

procedure TfrmScreenSaver.FormCreate(Sender : TObject);

begin
  Inherited;
  FLastNotifiedMousePosition.X := -1;
  ShowCursor(False) { Hide the mouse pointer }
end;

procedure TfrmScreenSaver.FormDestroy(Sender : TObject);

begin
  Inherited;
  ShowCursor(True) { Show the mouse pointer }
end;

procedure TfrmScreenSaver.WMKeyDown(var Msg : TWMKeyDown);

begin
  Close
end;

procedure TfrmScreenSaver.WMSysKeyDown(var Msg : TWMSysKeyDown);

begin
  Close
end;

end.
